package org.example.travel;

import org.example.booking.BookedOutException;
import org.example.booking.BookingService;
import org.example.logging.LoggingService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

@Service
public class TravelService {

	private final BookingService bookingService;
	private final LoggingService loggingService;

	public TravelService(BookingService bookingService, LoggingService loggingService) {
		this.bookingService = bookingService;
		this.loggingService = loggingService;
	}

	@Transactional(rollbackFor = BookedOutException.class)
	public void bookTravel(String destination, String customer) throws BookedOutException {
		loggingService.log("Booking travel to " + destination + " for " + customer);
		try {
			bookingService.bookFlight(destination, customer);
			bookingService.bookHotel(destination, customer);
		} catch (BookedOutException ex) {
			loggingService.log("Error: " + ex.getMessage());
			throw ex;
		}
	}
}
